summaryrefslogtreecommitdiff
path: root/src/modules/m_delayjoin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_delayjoin.cpp')
-rw-r--r--src/modules/m_delayjoin.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/m_delayjoin.cpp b/src/modules/m_delayjoin.cpp
index 7212b7b84..3a574d485 100644
--- a/src/modules/m_delayjoin.cpp
+++ b/src/modules/m_delayjoin.cpp
@@ -60,7 +60,7 @@ class ModuleDelayJoin : public Module
ModResult OnRawMode(User* user, Channel* channel, const char mode, const std::string &param, bool adding, int pcnt);
};
/* $ModDesc: Allows for delay-join channels (+D) where users dont appear to join until they speak */
ModeAction DelayJoinMode::OnModeChange(User* source, User* dest, Channel* channel, std::string &parameter, bool adding)
{
@@ -88,7 +88,7 @@ ModuleDelayJoin::~ModuleDelayJoin()
Version ModuleDelayJoin::GetVersion()
{
- return Version("Allows for delay-join channels (+D) where users dont appear to join until they speak", VF_VENDOR);
+ return Version("Allows for delay-join channels (+D) where users don't appear to join until they speak", VF_VENDOR);
}
void ModuleDelayJoin::OnNamesListItem(User* issuer, Membership* memb, std::string &prefixes, std::string &nick)
@@ -60,7 +60,7 @@ class ModuleDelayJoin : public Module
ModResult OnRawMode(User* user, Channel* channel, const char mode, const std::string &param, bool adding, int pcnt);
};
-/* $ModDesc: Allows for delay-join channels (+D) where users dont appear to join until they speak */
+/* $ModDesc: Allows for delay-join channels (+D) where users don't appear to join until they speak */
ModeAction DelayJoinMode::OnModeChange(User* source, User* dest, Channel* channel, std::string &parameter, bool adding)
{